package org.rcisoft.app.appApplication.controller;
/*固定导入*/

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import org.rcisoft.business.cmsApplication.entity.CmsApplication;
import org.rcisoft.business.cmsApplication.service.CmsApplicationService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * @author cy
 * @date 2024年3月25日 下午1:42:40
 */
@RestController
@RequestMapping("/app/cmsApplication")
public class AppApplicationController extends CyPaginationController<CmsApplication> {


    @Autowired
    private CmsApplicationService cmsApplicationServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('cms:application:singleSearch')")
    @CyOpeLogAnno(title = "system-报名管理-查询报名", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary = "查询单一报名", description = "查询单一报名")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true)})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsApplicationServiceImpl.findById(businessId));
    }

    @PreAuthorize("@cyPerm.hasPerm('sys:application:list')")
    @CyOpeLogAnno(title = "system-报名管理-查询报名管理", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary = "查询报名集合", description = "查询报名集合")
    @GetMapping(value = "/queryCmsApplication")
    public CyResult queryCmsApplication(CmsApplication cmsApplication) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsApplicationServiceImpl.findAll(cmsApplication));
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:application:pageSearch')")
    @CyOpeLogAnno(title = "system-报名管理-查询报名", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary = "分页查询报名集合", description = "分页查询报名集合")
    @GetMapping(value = "/queryCmsApplicationByPagination")
    public CyGridModel listByPagination(@RequestParam(required = false) Integer activityId, CmsApplication cmsApplication) {
        // 如果传入了 activityId，设置到 cmsApplication 对象中
        if (activityId != null) {
            cmsApplication.setActivityId(activityId);
        }

        // 调用分页查询的方法
        cmsApplicationServiceImpl.findAllByPagination(getPaginationUtility(), cmsApplication);

        // 返回分页结果
        return getGridModelResponse();
    }
}
